==> feathers-mailer-4.0.0.tgz: package/CHANGELOG.md <==
# Changelog

## [Unreleased](https://github.com/feathersjs-ecosystem/feathers-mailer/tree/HEAD)

[Full Changelog](https://github.com/feathersjs-ecosystem/feathers-mailer/compare/v3.1.0...HEAD)

**Merged pull requests:**

- npm update, Move to Github CI, Move to mocha@8 & Move to nyc [\#27](https://github.com/feathersjs-ecosystem/feathers-mailer/pull/27) ([fratzinger](https://github.com/fratzinger))
- fix typing error [\#24](https://github.com/feathersjs-ecosystem/feathers-mailer/pull/24) ([shakir-abdo](https://github.com/shakir-abdo))
- Update nodemailer to the latest version 🚀 [\#23](https://github.com/feathersjs-ecosystem/feathers-mailer/pull/23) ([greenkeeper[bot]](https://github.com/apps/greenkeeper))
- Update mocha to the latest version 🚀 [\#22](https://github.com/feathersjs-ecosystem/feathers-mailer/pull/22) ([greenkeeper[bot]](https://github.com/apps/greenkeeper))
- Update nodemailer to the latest version 🚀 [\#21](https://github.com/feathersjs-ecosystem/feathers-mailer/pull/21) ([greenkeeper[bot]](https://github.com/apps/greenkeeper))
- Update semistandard to the latest version 🚀 [\#20](https://github.com/feathersjs-ecosystem/feathers-mailer/pull/20) ([greenkeeper[bot]](https://github.com/apps/greenkeeper))
- Update debug to the latest version 🚀 [\#19](https://github.com/feathersjs-ecosystem/feathers-mailer/pull/19) ([greenkeeper[bot]](https://github.com/apps/greenkeeper))
- Clarify what you want for SMTP transporters... [\#18](https://github.com/feathersjs-ecosystem/feathers-mailer/pull/18) ([rayfoss](https://github.com/rayfoss))
- remove a historical callback [\#15](https://github.com/feathersjs-ecosystem/feathers-mailer/pull/15) ([bertho-zero](https://github.com/bertho-zero))

## [v3.1.0](https://github.com/feathersjs-ecosystem/feathers-mailer/tree/v3.1.0) (2021-08-03)

[Full Changelog](https://github.com/feathersjs-ecosystem/feathers-mailer/compare/v3.0.1...v3.1.0)

## [v3.0.1](https://github.com/feathersjs-ecosystem/feathers-mailer/tree/v3.0.1) (2018-06-03)

[Full Changelog](https://github.com/feathersjs-ecosystem/feathers-mailer/compare/v3.0.0...v3.0.1)

**Merged pull requests:**

- Update uberproto to the latest version 🚀 [\#14](https://github.com/feathersjs-ecosystem/feathers-mailer/pull/14) ([greenkeeper[bot]](https://github.com/apps/greenkeeper))
- Update broken links in README [\#13](https://github.com/feathersjs-ecosystem/feathers-mailer/pull/13) ([robbiedhickey](https://github.com/robbiedhickey))

## [v3.0.0](https://github.com/feathersjs-ecosystem/feathers-mailer/tree/v3.0.0) (2018-02-14)

[Full Changelog](https://github.com/feathersjs-ecosystem/feathers-mailer/compare/v2.0.0...v3.0.0)

**Merged pull requests:**

- Update to new plugin infrastructure [\#12](https://github.com/feathersjs-ecosystem/feathers-mailer/pull/12) ([daffl](https://github.com/daffl))
- Update mocha to the latest version 🚀 [\#11](https://github.com/feathersjs-ecosystem/feathers-mailer/pull/11) ([greenkeeper[bot]](https://github.com/apps/greenkeeper))
- Update semistandard to the latest version 🚀 [\#10](https://github.com/feathersjs-ecosystem/feathers-mailer/pull/10) ([greenkeeper[bot]](https://github.com/apps/greenkeeper))
- Update mocha to the latest version 🚀 [\#9](https://github.com/feathersjs-ecosystem/feathers-mailer/pull/9) ([greenkeeper[bot]](https://github.com/apps/greenkeeper))
- Update debug to the latest version 🚀 [\#8](https://github.com/feathersjs-ecosystem/feathers-mailer/pull/8) ([greenkeeper[bot]](https://github.com/apps/greenkeeper))

## [v2.0.0](https://github.com/feathersjs-ecosystem/feathers-mailer/tree/v2.0.0) (2017-07-04)

[Full Changelog](https://github.com/feathersjs-ecosystem/feathers-mailer/compare/v1.0.6...v2.0.0)

**Merged pull requests:**

- Update address-rfc2822 to the latest version 🚀 [\#7](https://github.com/feathersjs-ecosystem/feathers-mailer/pull/7) ([greenkeeper[bot]](https://github.com/apps/greenkeeper))
- Update semistandard to the latest version 🚀 [\#6](https://github.com/feathersjs-ecosystem/feathers-mailer/pull/6) ([greenkeeper[bot]](https://github.com/apps/greenkeeper))
- Update dependencies to enable Greenkeeper 🌴 [\#5](https://github.com/feathersjs-ecosystem/feathers-mailer/pull/5) ([greenkeeper[bot]](https://github.com/apps/greenkeeper))

## [v1.0.6](https://github.com/feathersjs-ecosystem/feathers-mailer/tree/v1.0.6) (2017-02-07)

[Full Changelog](https://github.com/feathersjs-ecosystem/feathers-mailer/compare/v1.0.5...v1.0.6)

**Merged pull requests:**

- Return a promise from create method [\#4](https://github.com/feathersjs-ecosystem/feathers-mailer/pull/4) ([rainum](https://github.com/rainum))
- jshint —\> semistandard [\#3](https://github.com/feathersjs-ecosystem/feathers-mailer/pull/3) ([corymsmith](https://github.com/corymsmith))

## [v1.0.5](https://github.com/feathersjs-ecosystem/feathers-mailer/tree/v1.0.5) (2016-09-30)

[Full Changelog](https://github.com/feathersjs-ecosystem/feathers-mailer/compare/v1.0.4...v1.0.5)

**Merged pull requests:**

- Return Promise if nodemailer provides one [\#2](https://github.com/feathersjs-ecosystem/feathers-mailer/pull/2) ([j2L4e](https://github.com/j2L4e))

## [v1.0.4](https://github.com/feathersjs-ecosystem/feathers-mailer/tree/v1.0.4) (2016-03-05)

[Full Changelog](https://github.com/feathersjs-ecosystem/feathers-mailer/compare/v1.0.3...v1.0.4)

**Closed issues:**

- Uberproto missing in package.json [\#1](https://github.com/feathersjs-ecosystem/feathers-mailer/issues/1)

## [v1.0.3](https://github.com/feathersjs-ecosystem/feathers-mailer/tree/v1.0.3) (2016-03-01)

[Full Changelog](https://github.com/feathersjs-ecosystem/feathers-mailer/compare/v1.0.2...v1.0.3)

## [v1.0.2](https://github.com/feathersjs-ecosystem/feathers-mailer/tree/v1.0.2) (2016-02-29)

[Full Changelog](https://github.com/feathersjs-ecosystem/feathers-mailer/compare/1.0.0...v1.0.2)

## [1.0.0](https://github.com/feathersjs-ecosystem/feathers-mailer/tree/1.0.0) (2016-02-29)

[Full Changelog](https://github.com/feathersjs-ecosystem/feathers-mailer/compare/ea67e3769ae41258194552d27607311e5a45e81d...1.0.0)



\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*

==> feathers-mailer-4.1.0.tgz: package/CHANGELOG.md <==
# Changelog

## [Unreleased](https://github.com/feathersjs-ecosystem/feathers-mailer/tree/HEAD)

[Full Changelog](https://github.com/feathersjs-ecosystem/feathers-mailer/compare/v4.0.0...HEAD)

**Merged pull requests:**

- feat!: typescript [\#33](https://github.com/feathersjs-ecosystem/feathers-mailer/pull/33) ([fratzinger](https://github.com/fratzinger))

## [v4.0.0](https://github.com/feathersjs-ecosystem/feathers-mailer/tree/v4.0.0) (2023-03-29)

[Full Changelog](https://github.com/feathersjs-ecosystem/feathers-mailer/compare/v3.1.0...v4.0.0)

**Closed issues:**

- find hook for mailer service is missing [\#31](https://github.com/feathersjs-ecosystem/feathers-mailer/issues/31)
- I created typings for this package - where to put them? [\#29](https://github.com/feathersjs-ecosystem/feathers-mailer/issues/29)
- out-of-date dependencies in npm package [\#28](https://github.com/feathersjs-ecosystem/feathers-mailer/issues/28)

## [v3.1.0](https://github.com/feathersjs-ecosystem/feathers-mailer/tree/v3.1.0) (2021-08-03)

[Full Changelog](https://github.com/feathersjs-ecosystem/feathers-mailer/compare/v3.0.1...v3.1.0)

**Merged pull requests:**

- npm update, Move to Github CI, Move to mocha@8 & Move to nyc [\#27](https://github.com/feathersjs-ecosystem/feathers-mailer/pull/27) ([fratzinger](https://github.com/fratzinger))
- fix typing error [\#24](https://github.com/feathersjs-ecosystem/feathers-mailer/pull/24) ([shakir-abdo](https://github.com/shakir-abdo))
- Update nodemailer to the latest version 🚀 [\#23](https://github.com/feathersjs-ecosystem/feathers-mailer/pull/23) ([greenkeeper[bot]](https://github.com/apps/greenkeeper))
- Update mocha to the latest version 🚀 [\#22](https://github.com/feathersjs-ecosystem/feathers-mailer/pull/22) ([greenkeeper[bot]](https://github.com/apps/greenkeeper))
- Update nodemailer to the latest version 🚀 [\#21](https://github.com/feathersjs-ecosystem/feathers-mailer/pull/21) ([greenkeeper[bot]](https://github.com/apps/greenkeeper))
- Update semistandard to the latest version 🚀 [\#20](https://github.com/feathersjs-ecosystem/feathers-mailer/pull/20) ([greenkeeper[bot]](https://github.com/apps/greenkeeper))
- Update debug to the latest version 🚀 [\#19](https://github.com/feathersjs-ecosystem/feathers-mailer/pull/19) ([greenkeeper[bot]](https://github.com/apps/greenkeeper))
- Clarify what you want for SMTP transporters... [\#18](https://github.com/feathersjs-ecosystem/feathers-mailer/pull/18) ([FossPrime](https://github.com/FossPrime))
- remove a historical callback [\#15](https://github.com/feathersjs-ecosystem/feathers-mailer/pull/15) ([bertho-zero](https://github.com/bertho-zero))

## [v3.0.1](https://github.com/feathersjs-ecosystem/feathers-mailer/tree/v3.0.1) (2018-06-03)

[Full Changelog](https://github.com/feathersjs-ecosystem/feathers-mailer/compare/v3.0.0...v3.0.1)

**Merged pull requests:**

- Update uberproto to the latest version 🚀 [\#14](https://github.com/feathersjs-ecosystem/feathers-mailer/pull/14) ([greenkeeper[bot]](https://github.com/apps/greenkeeper))
- Update broken links in README [\#13](https://github.com/feathersjs-ecosystem/feathers-mailer/pull/13) ([robbiedhickey](https://github.com/robbiedhickey))

## [v3.0.0](https://github.com/feathersjs-ecosystem/feathers-mailer/tree/v3.0.0) (2018-02-14)

[Full Changelog](https://github.com/feathersjs-ecosystem/feathers-mailer/compare/v2.0.0...v3.0.0)

**Merged pull requests:**

- Update to new plugin infrastructure [\#12](https://github.com/feathersjs-ecosystem/feathers-mailer/pull/12) ([daffl](https://github.com/daffl))
- Update mocha to the latest version 🚀 [\#11](https://github.com/feathersjs-ecosystem/feathers-mailer/pull/11) ([greenkeeper[bot]](https://github.com/apps/greenkeeper))
- Update semistandard to the latest version 🚀 [\#10](https://github.com/feathersjs-ecosystem/feathers-mailer/pull/10) ([greenkeeper[bot]](https://github.com/apps/greenkeeper))
- Update mocha to the latest version 🚀 [\#9](https://github.com/feathersjs-ecosystem/feathers-mailer/pull/9) ([greenkeeper[bot]](https://github.com/apps/greenkeeper))
- Update debug to the latest version 🚀 [\#8](https://github.com/feathersjs-ecosystem/feathers-mailer/pull/8) ([greenkeeper[bot]](https://github.com/apps/greenkeeper))

## [v2.0.0](https://github.com/feathersjs-ecosystem/feathers-mailer/tree/v2.0.0) (2017-07-04)

[Full Changelog](https://github.com/feathersjs-ecosystem/feathers-mailer/compare/v1.0.6...v2.0.0)

**Merged pull requests:**

- Update address-rfc2822 to the latest version 🚀 [\#7](https://github.com/feathersjs-ecosystem/feathers-mailer/pull/7) ([greenkeeper[bot]](https://github.com/apps/greenkeeper))
- Update semistandard to the latest version 🚀 [\#6](https://github.com/feathersjs-ecosystem/feathers-mailer/pull/6) ([greenkeeper[bot]](https://github.com/apps/greenkeeper))
- Update dependencies to enable Greenkeeper 🌴 [\#5](https://github.com/feathersjs-ecosystem/feathers-mailer/pull/5) ([greenkeeper[bot]](https://github.com/apps/greenkeeper))

## [v1.0.6](https://github.com/feathersjs-ecosystem/feathers-mailer/tree/v1.0.6) (2017-02-07)

[Full Changelog](https://github.com/feathersjs-ecosystem/feathers-mailer/compare/v1.0.5...v1.0.6)

**Merged pull requests:**

- Return a promise from create method [\#4](https://github.com/feathersjs-ecosystem/feathers-mailer/pull/4) ([rainum](https://github.com/rainum))
- jshint —\> semistandard [\#3](https://github.com/feathersjs-ecosystem/feathers-mailer/pull/3) ([corymsmith](https://github.com/corymsmith))

## [v1.0.5](https://github.com/feathersjs-ecosystem/feathers-mailer/tree/v1.0.5) (2016-09-30)

[Full Changelog](https://github.com/feathersjs-ecosystem/feathers-mailer/compare/v1.0.4...v1.0.5)

**Merged pull requests:**

- Return Promise if nodemailer provides one [\#2](https://github.com/feathersjs-ecosystem/feathers-mailer/pull/2) ([j2L4e](https://github.com/j2L4e))

## [v1.0.4](https://github.com/feathersjs-ecosystem/feathers-mailer/tree/v1.0.4) (2016-03-05)

[Full Changelog](https://github.com/feathersjs-ecosystem/feathers-mailer/compare/v1.0.3...v1.0.4)

**Closed issues:**

- Uberproto missing in package.json [\#1](https://github.com/feathersjs-ecosystem/feathers-mailer/issues/1)

## [v1.0.3](https://github.com/feathersjs-ecosystem/feathers-mailer/tree/v1.0.3) (2016-03-01)

[Full Changelog](https://github.com/feathersjs-ecosystem/feathers-mailer/compare/v1.0.2...v1.0.3)

## [v1.0.2](https://github.com/feathersjs-ecosystem/feathers-mailer/tree/v1.0.2) (2016-02-29)

[Full Changelog](https://github.com/feathersjs-ecosystem/feathers-mailer/compare/1.0.0...v1.0.2)

## [1.0.0](https://github.com/feathersjs-ecosystem/feathers-mailer/tree/1.0.0) (2016-02-29)

[Full Changelog](https://github.com/feathersjs-ecosystem/feathers-mailer/compare/ea67e3769ae41258194552d27607311e5a45e81d...1.0.0)



\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*
